@@ -146,8 +146,14 @@ class MediaShowListingView(BrowserView):
                 results = catalog.searchResults(item.buildQuery())[:item.itemCount]
             else:
                 results = catalog.searchResults(item.buildQuery())
-        elif item.portal_type == "Category Navigator" and hasattr(self.request, 'Subject'):
-            results = catalog.searchResults(Subject = self.request['Subject'])
+        #TODO: This next part was made for porseleinplaats website to work with the category navigator and Object type
+        #it is a hack and should be revised. the whole query string should be parsed into the search.
+        #also found a problem where User objects get a wrong Image media url.
+        elif item.portal_type == "Category Navigator" and (hasattr(self.request, 'Subject') or hasattr(self.request, 'Creator')):
+            if hasattr(self.request, 'Subject'):
+                results = catalog.searchResults(Subject = self.request['Subject'])
+            elif hasattr(self.request, 'Creator'):
+                results = catalog.searchResults(Creator = self.request['Creator'], portal_type = 'Object')
         else:
             results = []
          
